==> nextcloud-app-mail-0.7.10-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/fi.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Sähköposti",
    "Loading accounts" : "Ladataan tilejä",
    "Error while loading the accounts." : "Virhe tilejä ladatessa.",
    "Error while loading the selected account." : "Virhe ladatessa valittua tiliä.",
    "Can not load this folder." : "Tätä kansiota ei voitu ladata.",
    "Searching for {query}" : "Etsitään tuloksia haulle {query}",
    "Error while deleting message." : "Virhe viestiä poistaessa.",
    "Forwarded message" : "Edelleenlähetetty viesti",
    "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
    "Attachments saved to Files." : "Liitteet tallennettu tiedostoihin.",
    "Attachment saved to Files." : "Liite tallennettu tiedostoihin.",
    "Error while saving attachments to Files." : "Virhe tallennettaessa liitteitä tiedostoihin.",
    "Error while saving attachment to Files." : "Virhe tallennettaessa liitettä tiedostoihin.",
    "Message flag could not be set." : "Viestin lippua ei voitu asettaa.",
    "Could not move message." : "Viestiä ei voitu siirtää.",
    "Invalid account" : "Virheellinen tili",
    "Invalid folder" : "Virheellinen kansio",
    "Error while creating the account: " : "Virhe tiliä luotaessa: ",
    "Unknown error" : "Tuntematon virhe",
    "Error while updating the account: " : "Virhe päivittäessä tiliä:",
    "All inboxes" : "Kaikki saapuneiden laatikot",
    "you" : "sinä",
    "Send message to {email}" : "Lähetä viesti osoitteeseen {email}",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ei voitu ladata",
    "There was a problem loading {tag}{name}{endtag}" : "Ladattaessa {tag}{name}{endtag} ilmeni ongelma",
    "Could not load your message" : "Viestiä ei voitu ladata",
    "Could not load the desired message" : "Haluttua viestiä ei voitu ladata",
    "Could not load the message" : "Viestiä ei voitu ladata",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n uusi viesti \nlähettäjältä {from}","%n uutta viestiä \nlähettäjältä {from}"],
    "Nextcloud Mail" : "Nextcloud-sähköposti",
    "Save" : "Tallenna",
    "Saved" : "Tallennettu",
    "Show all folders" : "Näytä kaikki kansiot",
    "Collapse folders" : "Supista kansiot",
    "Error while deleting account." : "Virhe tiliä poistaessa.",
    "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
    "An error occurred while uploading {fname}" : "Virhe lähettäessä tiedostoa {fname}",
    "Reply" : "Vastaa",
    "Send" : "Lähetä",
    "Sending …" : "Lähetetään…",
    "Message sent!" : "Viesti lähetetty!",
    "Server error" : "Palvelinvirhe",
    "An unknown error occurred" : "Tapahtui tuntematon virhe",
    "Opening HTML drafts is not supported yet." : "HTML-luonnosten avaaminen ei ole vielä tuettu ominaisuus.",
    "No writable calendars found" : "Kirjoitusoikeudella olevia kalentereita ei löytynyt",
    "Error while importing the calendar event" : "Virhe kalenteritapahtumaa tuotaessa",
    "Error while downloading calendar event" : "Virhe kalenteritapahtumaa ladatessa",
    "& others" : "& muut",
    "Error while loading messages." : "Virhe viestejä ladatessa.",
    "Error while refreshing messages." : "Virhe viestejä päivittäessä.",
    "Setting up your account" : "Määritetään tiliäsi",
    "Inbox" : "Saapuneet",
    "Sent" : "Lähetetyt",
    "Drafts" : "Luonnokset",
    "Archive" : "Arkisto",
    "Trash" : "Roskakori",
    "Junk" : "Roskaposti",
    "All" : "Kaikki",
    "Favorites" : "Suosikit",
    "Auto detect failed. Please use manual mode." : "Automaattinen havaitseminen epäonnistui. Käytä manuaalitilaa.",
    "Updating account failed: " : "Tilin päivittäminen epäonnistui:",
    "Creating account failed: " : "Tilin luominen epäonnistui:",
    "Delete permanently" : "Poista pysyvästi",
    "Error loading message" : "Virhe viestiä ladatessa",
    "Settings" : "Asetukset",
    "Forwarding to %s" : "Välitä viesti %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikkaa jos sinua ei uudelleenohjata automaattisesti muutamaan sekuntiin.",
    "Redirect" : "Uudelleenohjaus",
    "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jos et halua vierailla kyseisellä sivulla, voit palata <a href=\"%s\">sähköpostiin</a>.",
    "Continue to %s" : "Jatka sivulle %s",
    "Delete account" : "Poista tili",
    "Try again" : "Yritä uudelleen",
    "New message" : "Uusi viesti",
    "Account Settings" : "Tilin asetukset",
    "Aliases" : "Aliakset",
    "Mail address" : "Sähköpostiosoite",
    "Display Name" : "Näyttönimi",
    "Account" : "Tili",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Speed up your Mail experience with these quick shortcuts." : "Nopeuta sähköpostikokemustasi näillä pikanäppäimillä.",
    "Compose new message" : "Uusi viesti",
    "Newer message" : "Uudempi",
    "Older message" : "Vanhempi viesti",
    "Toggle star" : "Lisää/poista tähti",
    "Toggle unread" : "Merkitse luetuksi/lukemattomaksi",
    "Delete" : "Poista",
    "Search" : "Etsi",
    "Refresh" : "Päivitä",
    "Connect your mail account" : "Yhdistä sähköpostitilisi",
    "Name" : "Nimi",
    "Mail Address" : "Sähköpostiosoite",
    "Password" : "Salasana",
    "Manual configuration" : "Manuaalinen konfiguraatio",
    "IMAP Host" : "IMAP-palvelin",
    "IMAP security" : "IMAP-yhteyden suojaus",
    "None" : "Ei mitään",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-portti",
    "IMAP User" : "IMAP-käyttäjä",
    "IMAP Password" : "IMAP-salasana",
    "SMTP Host" : "SMTP-palvelin",
    "SMTP security" : "SMTP-yhteyden suojaus",
    "SMTP Port" : "SMTP-portti",
    "SMTP User" : "SMTP-käyttäjä",
    "SMTP Password" : "SMTP-salasana",
    "Connect" : "Yhdistä",
    "from" : "Lähettäjä",
    "to" : "Vastaanottaja",
    "cc" : "Kopio",
    "bcc" : "Piilokopio",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Huomioi, että viesti saapui noreply-osoitteesta (ns. älä vastaa -osoite), joten vastausviestiäsi tuskin luetaan.",
    "Subject" : "Aihe",
    "Save all to Files" : "Tallenna kaikki tiedostoihin",
    "Add mail account" : "Lisää sähköpostitili",
    "No search results for" : "Ei tuloksia haulle",
    "The images have been blocked to protect your privacy." : "Kuvat estettiin yksityisyytesi suojelemiseksi.",
    "Show images from this sender" : "Näytä kuvat tältä lähettäjältä",
    "Forward" : "Välitä",
    "No messages in this folder!" : "Tässä kansiossa ei ole viestejä!",
    "Upload attachment" : "Lähetä liite",
    "Add attachment from Files" : "Lisää liitteitä tiedostosovelluksesta",
    "Import into calendar" : "Tuo kalenteriin",
    "Download attachment" : "Lataa liite",
    "Save to Files" : "Tallenna tiedostoihin"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.8.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/fi.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Sähköposti",
    "Loading accounts" : "Ladataan tilejä",
    "Error while loading the accounts." : "Virhe tilejä ladatessa.",
    "Can not load this folder." : "Tätä kansiota ei voitu ladata.",
    "Searching for {query}" : "Etsitään tuloksia haulle {query}",
    "Error while deleting message." : "Virhe viestiä poistaessa.",
    "Forwarded message" : "Edelleenlähetetty viesti",
    "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
    "Attachments saved to Files." : "Liitteet tallennettu tiedostoihin.",
    "Attachment saved to Files." : "Liite tallennettu tiedostoihin.",
    "Error while saving attachments to Files." : "Virhe tallennettaessa liitteitä tiedostoihin.",
    "Error while saving attachment to Files." : "Virhe tallennettaessa liitettä tiedostoihin.",
    "Message flag could not be set." : "Viestin lippua ei voitu asettaa.",
    "Could not move message." : "Viestiä ei voitu siirtää.",
    "Invalid account" : "Virheellinen tili",
    "Invalid folder" : "Virheellinen kansio",
    "Error while creating the account: " : "Virhe tiliä luotaessa: ",
    "Unknown error" : "Tuntematon virhe",
    "Error while updating the account: " : "Virhe päivittäessä tiliä:",
    "All inboxes" : "Kaikki saapuneiden laatikot",
    "you" : "sinä",
    "Send message to {email}" : "Lähetä viesti osoitteeseen {email}",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ei voitu ladata",
    "There was a problem loading {tag}{name}{endtag}" : "Ladattaessa {tag}{name}{endtag} ilmeni ongelma",
    "Could not load your message" : "Viestiä ei voitu ladata",
    "Could not load the desired message" : "Haluttua viestiä ei voitu ladata",
    "Could not load the message" : "Viestiä ei voitu ladata",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n uusi viesti \nlähettäjältä {from}","%n uutta viestiä \nlähettäjältä {from}"],
    "Nextcloud Mail" : "Nextcloud-sähköposti",
    "Save" : "Tallenna",
    "Saved" : "Tallennettu",
    "Show all folders" : "Näytä kaikki kansiot",
    "Collapse folders" : "Supista kansiot",
    "Error while deleting account." : "Virhe tiliä poistaessa.",
    "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
    "An error occurred while uploading {fname}" : "Virhe lähettäessä tiedostoa {fname}",
    "Reply" : "Vastaa",
    "Send" : "Lähetä",
    "Sending …" : "Lähetetään…",
    "Message sent!" : "Viesti lähetetty!",
    "Server error" : "Palvelinvirhe",
    "An unknown error occurred" : "Tapahtui tuntematon virhe",
    "Opening HTML drafts is not supported yet." : "HTML-luonnosten avaaminen ei ole vielä tuettu ominaisuus.",
    "No writable calendars found" : "Kirjoitusoikeudella olevia kalentereita ei löytynyt",
    "Error while importing the calendar event" : "Virhe kalenteritapahtumaa tuotaessa",
    "Error while downloading calendar event" : "Virhe kalenteritapahtumaa ladatessa",
    "& others" : "& muut",
    "Error while loading messages." : "Virhe viestejä ladatessa.",
    "Error while refreshing messages." : "Virhe viestejä päivittäessä.",
    "Setting up your account" : "Määritetään tiliäsi",
    "Inbox" : "Saapuneet",
    "Sent" : "Lähetetyt",
    "Drafts" : "Luonnokset",
    "Archive" : "Arkisto",
    "Trash" : "Roskakori",
    "Junk" : "Roskaposti",
    "All" : "Kaikki",
    "Favorites" : "Suosikit",
    "Auto detect failed. Please use manual mode." : "Automaattinen havaitseminen epäonnistui. Käytä manuaalitilaa.",
    "Updating account failed: " : "Tilin päivittäminen epäonnistui:",
    "Creating account failed: " : "Tilin luominen epäonnistui:",
    "Delete permanently" : "Poista pysyvästi",
    "Error loading message" : "Virhe viestiä ladatessa",
    "Settings" : "Asetukset",
    "Forwarding to %s" : "Välitä viesti %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikkaa jos sinua ei uudelleenohjata automaattisesti muutamaan sekuntiin.",
    "Redirect" : "Uudelleenohjaus",
    "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jos et halua vierailla kyseisellä sivulla, voit palata <a href=\"%s\">sähköpostiin</a>.",
    "Continue to %s" : "Jatka sivulle %s",
    "Delete account" : "Poista tili",
    "Try again" : "Yritä uudelleen",
    "New message" : "Uusi viesti",
    "Account Settings" : "Tilin asetukset",
    "Aliases" : "Aliakset",
    "Mail address" : "Sähköpostiosoite",
    "Display Name" : "Näyttönimi",
    "Account" : "Tili",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Speed up your Mail experience with these quick shortcuts." : "Nopeuta sähköpostikokemustasi näillä pikanäppäimillä.",
    "Compose new message" : "Uusi viesti",
    "Newer message" : "Uudempi",
    "Older message" : "Vanhempi viesti",
    "Toggle star" : "Lisää/poista tähti",
    "Toggle unread" : "Merkitse luetuksi/lukemattomaksi",
    "Delete" : "Poista",
    "Search" : "Etsi",
    "Refresh" : "Päivitä",
    "Connect your mail account" : "Yhdistä sähköpostitilisi",
    "Name" : "Nimi",
    "Mail Address" : "Sähköpostiosoite",
    "Password" : "Salasana",
    "Manual configuration" : "Manuaalinen konfiguraatio",
    "IMAP Host" : "IMAP-palvelin",
    "IMAP security" : "IMAP-yhteyden suojaus",
    "None" : "Ei mitään",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-portti",
    "IMAP User" : "IMAP-käyttäjä",
    "IMAP Password" : "IMAP-salasana",
    "SMTP Host" : "SMTP-palvelin",
    "SMTP security" : "SMTP-yhteyden suojaus",
    "SMTP Port" : "SMTP-portti",
    "SMTP User" : "SMTP-käyttäjä",
    "SMTP Password" : "SMTP-salasana",
    "Connect" : "Yhdistä",
    "from" : "Lähettäjä",
    "to" : "Vastaanottaja",
    "cc" : "Kopio",
    "bcc" : "Piilokopio",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Huomioi, että viesti saapui noreply-osoitteesta (ns. älä vastaa -osoite), joten vastausviestiäsi tuskin luetaan.",
    "Subject" : "Aihe",
    "Save all to Files" : "Tallenna kaikki tiedostoihin",
    "Add mail account" : "Lisää sähköpostitili",
    "No search results for" : "Ei tuloksia haulle",
    "The images have been blocked to protect your privacy." : "Kuvat estettiin yksityisyytesi suojelemiseksi.",
    "Show images from this sender" : "Näytä kuvat tältä lähettäjältä",
    "Forward" : "Välitä",
    "No messages in this folder" : "Tässä kansiossa ei ole viestejä",
    "Upload attachment" : "Lähetä liite",
    "Add attachment from Files" : "Lisää liitteitä tiedostosovelluksesta",
    "Import into calendar" : "Tuo kalenteriin",
    "Download attachment" : "Lataa liite",
    "Save to Files" : "Tallenna tiedostoihin"
},
"nplurals=2; plural=(n != 1);");
